@@ -689,16 +689,16 @@ class CiscoIOSConfigParser(IndentedContextualConfigParser):
             dst_port = " %s" % groups["icmp_type"]
 
 
-        established = groups.get("established", "")
+        established = groups["established"] or ""
 
-        qos = groups.get("qos", "")
+        qos = groups["qos"] or ""
 
-        log = groups.get("log", "")
+        log = groups["log"] or ""
 
 
-        return "%s %s %s%s %s%s%s%s" % (
+        return "%s %s %s%s %s%s%s%s%s" % (
                    action, protocol, src_addr, src_port, dst_addr, dst_port,
-                   established, qos)
+                   established, qos, log)
 
 
     _CMD_ACL_EXTNUM_RE = (
@@ -850,9 +850,9 @@ class CiscoIOSConfigParser(IndentedContextualConfigParser):
             dst_port = " %s" % groups["icmp_type"]
 
 
-        established = groups.get("established", "")
+        established = groups["established"] or ""
 
-        log = groups.get("log", "")
+        log = groups["log"] or ""
 
 
         return ("{action} {protocol} {src_addr}{src_port} "
